<?php
/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    SR_Partner
 * @subpackage SR_Partner/public
 * @author     Ryan Magbanua <ryan@getreview.co>
 */
class SR_Partner_Public extends SR_Partner_Core {

    /**
     * The ID of this plugin.
     *
     * @since    1.0.0
     * @access   private
     * @var      string    $plugin_name    The ID of this plugin.
     */
    private $plugin_name;

    /**
     * The version of this plugin.
     *
     * @since    1.0.0
     * @access   private
     * @var      string    $version    The current version of this plugin.
     */
    private $version;

    /**
     * Initialize the class and set its properties.
     *
     * @since    1.0.0
     * @param      string    $plugin_name       The name of this plugin.
     * @param      string    $version    The version of this plugin.
     */
    public function __construct( $plugin_name, $version )
    {        
        parent::__construct();
        $this->plugin_name = $plugin_name;
        $this->version = $version;
        $this->add_shortcode();
    }

    
    /**
     * WebAudit hook checker to all pages
     *
     * @since    1.0.0
     */
    public function hook_to_all_pages()
    {
        $audit_is_active = get_option(PARTNER_PLUGIN_STATUS);
        $audit_is_active = $audit_is_active !== false ? true : false;

        if ($audit_is_active) {
            $id = get_option(SR_PARTNER_INSTALL_TO_ALL_PAGES);
            if (is_numeric($id)) {
                echo $this->_db->get_shortcode($id)->embed_code;
            }
        }

        //this for localization of audit widget
        //this for localization of audit widget
        $audit_is_active = get_option(PARTNER_PLUGIN_STATUS);
        $audit_is_active = $audit_is_active !== false ? $audit_is_active : false;

        if ($audit_is_active == 1) {  
            $js = '
                <script type="text/javascript">    
                var sr_partner_localization = {
                    run_audit           : "'. __("Run Audit","sr-partner") .'",
                    running_audit       : "'. __("Running your web audit.","sr-partner") .'",
                    please_wait         : "'. __("Please wait...","sr-partner") .'",
                    success             : "'. __("Success!","sr-partner") .'",
                    oh_snap             : "'. __("Oh snap!","sr-partner") .'",
                    error_occured       : "'. __("There was a problem processing your request. Please try again.","sr-partner") .'",
                    web_url_required    : "'. __("Website URL is required.","sr-partner") .'",
                    web_url_invalid     : "'. __("Website URL is invalid.","sr-partner") .'",
                    email_required      : "'. __("Email is required.","sr-partner") .'",
                    email_invalid       : "'. __("Email is invalid.","sr-partner") .'",
                };
                </script>
            ';
            echo $js;
        }
        //this for localization of audit widget
        //this for localization of audit widget
    }

    /**
     * Add a shortcode listener to WP
     *
     * @since       1.0.0
     * @param       Array       $params - array of shortcode info
     * @return      String      $string - html value of the shortcode
     */
    public function hook_shortcode($params = array())
    {

        $audit_is_active = get_option(PARTNER_PLUGIN_STATUS);
        $audit_is_active = $audit_is_active !== false ? $audit_is_active : 0;    
        if ($audit_is_active) {
            if (isset($params['id'])) {
                $short_code_id = intval($params['id']);
                return $this->_db->get_shortcode($short_code_id)->embed_code;
            }
        }
    }
    
    /**
     * Add a shortcode listener to WP
     *
     * @since    1.0.0
     */
    public function add_shortcode()
    {
        add_shortcode('sr-partner-os-audit', array($this, 'hook_shortcode' ));
    }

    /**
     * Catches the ajax call from front end using the widget
     *
     * @since    1.0.0
     * @return   outputs the json data of the result
     */
    public function sr_partner_ajax()
    {
        $response = array (
            'statusCode'    => 422,
            'response'      => array (
                'error'     => 'Failed'
            )
        );

        if ($_POST && isset($_POST['email']) && isset($_POST['url'])) {

            $email      = sanitize_text_field($_POST['email']);
            $url        = sanitize_text_field($_POST['url']);
            $source_url = sanitize_text_field($_POST['source_url']);
            $ip         = $this->_helper->get_user_ip();
            $has_error  = false;
            $err_msg    = "";

            if (is_email($email)) {

                if (strpos($url,'http://') === false && strpos($url,'https://') === false) {
                    $url = 'http://'.$url;
                }

                $site_response = wp_remote_get( $url,
                    array(
                        'timeout'     => 10,
                    )
                );
                if ( is_wp_error( $site_response ) ) {
                    $has_error  = true;
                    $err_msg    = __("The website you are trying to audit cannot be reached right now. Please try again later.","sr-partner");
                } else {

                    //url ok here... do the API Call now
                    //url ok here... do the API Call now
                    $key = $this->_helper->get_key();
                    if (empty($key)) {                        
                        $has_error  = true;
                        $err_msg    = __("An error has occured. Please contact the administrator.","sr-partner");
                    }

                    $key = preg_replace('/\d+\//i', '', $key); // this will remove the number that is prepend from the token
                    
                    $params = array(
                      "email" => $email,
                      "url" => $url,
                      "token" => $key,
                      "source_url" => $source_url,
                      "ip" => $ip,
                    );
                    $api_params['url']          = SR_PARTNER_GENERATE_URL.'/generate';
                    $api_params['post_string']  = $params;

                    $res            = $this->_helper->call_api($api_params);

                    if (!empty($res)) {
                        $post_response  = json_decode($res, true);
                    } else {
                        $post_response = [
                            'statusCode' => '422',
                            'response'   => ['error' => __("There was a problem processing your request. Please try again.","sr-partner")]
                        ];
                    }

                    echo json_encode($post_response);
                    //url ok here... do the API Call now
                    //url ok here... do the API Call now
                }

               
            } else {
                $has_error  = true;
                $err_msg    = __("Invalid email.","sr-partner");
            }

            if ($has_error) {
                $response['data']['error'] = $err_msg;
                echo json_encode($response);
            }        

        } else {
            $response['data']['error'] = __("Invalid POST parameters.","sr-partner");
            echo json_encode($response);
        }        
        wp_die();
    }

    /**
     * Hook that checks if the current page is same with SR_PARTNER_DASHBOARD_PAGE_INFO or SR_PARTNER_PORTFOLIO_PAGE_INFO
     *
     * @since    1.0.0
     */
    public function public_init_hook()
    {
        $dashboard_info     = get_option(SR_PARTNER_DASHBOARD_PAGE_INFO);
        $portfolio_info     = get_option(SR_PARTNER_PORTFOLIO_PAGE_INFO);
        $token              = $this->_helper->get_key();
        $token              = !$token ? "" : $token;
        $key                = preg_replace('/\d+\//i', '', $token); // this will remove the number that is prepend from the token
       
        if ($dashboard_info !== false || $portfolio_info !== false) {

            $current_url= $_SERVER['HTTP_HOST'].$_SERVER['REQUEST_URI'];

            if ($dashboard_info !== false) {
                $dashboard_info = unserialize($dashboard_info);

                if (isset($dashboard_info['permalink']) && !empty($dashboard_info['permalink'])) {
                    $dashboard_permalink = $this->remove_http($dashboard_info['permalink']);    

                    if ($dashboard_permalink == $current_url) {
                        $params['page_id']  = $dashboard_info['id'];
                        $params['title']    = $dashboard_info['title'];
                        $params['url']      = SR_PARTNER_DASHBOARD_URL.$token;                    
                        $this->output_custom_page($params);
                    }
                }
                
            }

            if ($portfolio_info !== false) {
                $portfolio_info = unserialize($portfolio_info);

                if (isset($portfolio_info['permalink']) && !empty($portfolio_info['permalink'])) {
                    $portfolio_permalink = $this->remove_http($portfolio_info['permalink']);    

                    if ($portfolio_permalink == $current_url) {

                        $params['page_id']  = $portfolio_info['id'];
                        $params['title']    = $portfolio_info['title'];
                        $params['url']      = SR_PARTNER_PORTFOLIO_URL.$key.'/portfolio';
                        
                        $this->output_custom_page($params);
                    }
                }
            }
        }
    }

    /**
     * Register the stylesheets for the public-facing side of the site.
     *
     * @since    1.0.0
     */
    public function enqueue_styles()
    {        
        $audit_is_active = get_option(PARTNER_PLUGIN_STATUS);
        $audit_is_active = $audit_is_active !== false ? $audit_is_active : false;
        if ($audit_is_active == 1) {            
            wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/sr-partner-public.css', array(), $this->version, 'all' );
        }
    }

    /**
     * Register the JavaScript for the public-facing side of the site.
     *
     * @since    1.0.0
     */
    public function enqueue_scripts()
    {
        $audit_is_active = get_option(PARTNER_PLUGIN_STATUS);
        $audit_is_active = $audit_is_active !== false ? $audit_is_active : false;
        if ($audit_is_active == 1) {            
            wp_enqueue_script( $this->plugin_name . '-public', plugin_dir_url( __FILE__ ) . 'js/sr-partner-public.js', array( 'jquery' ), $this->version, true );
            wp_localize_script( $this->plugin_name . '-public', 'sr_partner_ajax_object', array( 'ajax_url' => admin_url( 'admin-ajax.php' ) ) );
        }
        

    }

    /*** private functions ****/
    /**
     * Outputs the custom page to browser
     *
     * @since    1.0.0
     * @param       Array       $params - array info need to output
     */
    private function output_custom_page($params)
    {
        /**************/
        $html = '
            <!DOCTYPE html>
                <html>
                    <head>
                        <title>'.$params['title'].'</title>
                        <style>
                            html, body {
                                margin: 0;
                                overflow: hidden;
                                padding: 0;
                            }
                        </style>
                    </head>
                <body><iframe src="'.$params['url'].'" style="border:none; width:100%; height:100%; position:absolute;"></iframe></body>
            </html>
        ';
        echo $html;
        exit();
    }

    /**
     * Removes http and https int the url
     *
     * @since    1.0.0
     * @param    $url - URL
     * @return   $url - string
     */
    private function remove_http($url)
    {

       $disallowed = array('http://', 'https://');
       foreach($disallowed as $d) {
          if (strpos($url, $d) === 0) {
             return str_replace($d, '', $url);
          }
       }
       return $url;
    }
}
